!><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>
!
! Yin-Yang-dynamo-mpi: MHD dynamo simulation by the Yin-Yang grid.
!
! - Parallel version by MPI.
!
! - Code distribution: 2011.03.28 (for Kotake-san and Takiwaki-san).
! 
! - I hope this code is helpful for your study.
!
! - Refences:
!     >  Akira Kageyama and Tetsuya Sato,
!     >  "Yin-Yang grid": An Overset Grid in Spherical Geometry,   
!     >  Geochem. Geophys. Geosyst., doi:10.1029/2004GC000734, 2004
!
!     >  Akira Kageyama
!     >  Dissection of a Sphere and Yin-Yang Grids
!     >  J. Earth Simulator, 2005, vol.3, pp.20-28
!
! - Please do not remove my comments.
!
! - Please send me your feedback to:
!              Akira Kageyama, 
!              Kobe University
!              email: kage@cs.kobe-u.ac.jp
!
!><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>
! constants.f90
!              2003.05.28: Created by Akira Kageyama
!              2003.09.54: New parameter FILE_PRINTOUT.
!              2004.03.30: Added new parameters; N_SYSTEM and E_SYSTEM.
!              2004.03.30: Added new parameters; KEY_C_FIELD_FR, and others.
!              2004.04.05: Removed AVS andVFIVE related constants.
!              2004.04.05: Removed KEY_C_FIELD_FR, etc.
!              2006.01.14: This is yymm-hs-mhd-mpi3.
!              2006.01.20: DP=selected_real_kind(2*precision(1.0_SP)).
!              2006.01.14: This is yymm-hs-mhd-mpi3p1.
!              2006.02.28: Added FILE_MAG_MOMENTS.
!              2006.08.22: FILE_3D_DATA --> FILE_3D_WYN_DATA.
!><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>

module constants      
!*****************************************************************************
! MODULE CONSTANTS                                 Constants with Global Scope
!*****************************************************************************
  implicit none

  !<< f90 constants >>!
  integer, parameter :: SP = kind(1.0)
  integer, parameter :: DP = selected_real_kind(2*precision(1.0_SP))
  integer, parameter :: DPC = kind((1.0_DP,1.0_DP))

  !<< Mathematical constants >>!
  real(DP), parameter     :: PI = 3.141592653589793238462643383279502884_DP
  real(DP), parameter     :: TWOPI = PI*2
  complex(DPC), parameter :: Z0 = (0.0_DP,0.0_DP)
  complex(DPC), parameter :: ZI = (0.0_DP,1.0_DP)

  !<< Job karte >>!
  integer, parameter :: KARTE_SUCCESS           =  0
  integer, parameter :: KARTE_TIME_OUT          =  1
  integer, parameter :: KARTE_OVERFLOW          =  2
  integer, parameter :: KARTE_UNDERFLOW         =  3
  integer, parameter :: KARTE_NEGATIVE_ANORMALY =  4

  !<< I/O >>!
  integer, parameter :: FILE_NAMELIST       = 05
  integer, parameter :: FILE_STANDARD_OUT   = 06

  integer, parameter :: FILE_OLD_RESTART    = 80
  integer, parameter :: FILE_NEW_RESTART    = 81
  integer, parameter :: FILE_2D_DATA_MIDTHT = 50
  integer, parameter :: FILE_3D_WYN_DATA    = 52
  integer, parameter :: FILE_FLOW_ENERGY    = 70
  integer, parameter :: FILE_MAG_ENERGY     = 71
  integer, parameter :: FILE_TOTAL_MASS     = 72
  integer, parameter :: FILE_MAG_MOMENTS    = 73
  
  ! Added by Kouhei Yamada 2011/11/24
  integer, parameter :: FILE_2D_DATA_MIDTHT_RAD = 74

  !<< I/O file name length >>!
  integer, parameter :: TAG_STRING_LENGTH_MAX = 100
  integer, parameter :: FILE_NAME_LENGTH_MAX  = TAG_STRING_LENGTH_MAX + 50

  !<< "color" of the process >>!
  integer, parameter :: COLOR_YIN  = 0  ! Don't change these, used as:
  integer, parameter :: COLOR_YANG = 1  ! array(COLOR_YIN:COLOR_YANG)

  !<< "color" of the process >>!
  character(len=1), parameter :: CHAR_SLASH = '/'
  character(len=1), parameter :: CHAR_UBAR  = '_'
  character(len=1), parameter :: CHAR_DOT   = '.'

end module constants
